summaryrefslogtreecommitdiffstats
path: root/qtjava/javalib/org/kde/qt/QSocketNotifier.java
diff options
context:
space:
mode:
Diffstat (limited to 'qtjava/javalib/org/kde/qt/QSocketNotifier.java')
-rw-r--r--qtjava/javalib/org/kde/qt/QSocketNotifier.java34
1 files changed, 17 insertions, 17 deletions
diff --git a/qtjava/javalib/org/kde/qt/QSocketNotifier.java b/qtjava/javalib/org/kde/qt/QSocketNotifier.java
index bae73507..4e9bcb7f 100644
--- a/qtjava/javalib/org/kde/qt/QSocketNotifier.java
+++ b/qtjava/javalib/org/kde/qt/QSocketNotifier.java
@@ -7,7 +7,7 @@ import org.kde.qt.Qt;
*************************************************
$Id$
* Definition of QSocketNotifier class
* Created : 951114
@@ -17,7 +17,7 @@ import org.kde.qt.Qt;
* This file may be distributed under the terms of the Q Public License
as defined by Trolltech AS of Norway and appearing in the file
- LICENSE.QPL included in the packaging of this file.
+ LICENSE.TQPL included in the packaging of this file.
* This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
@@ -33,46 +33,46 @@ import org.kde.qt.Qt;
* See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
information about Qt Commercial License Agreements.
- See http://www.trolltech.com/qpl/ for QPL licensing information.
+ See http://www.trolltech.com/qpl/ for TQPL licensing information.
See http://www.trolltech.com/gpl/ for GPL licensing information.
* Contact info@trolltech.com if any conditions of this licensing are
not clear to you.
********************************************** See {@link QSocketNotifierSignals} for signals emitted by QSocketNotifier
@short $Id: qt/qsocketnotifier.
*/
-public class QSocketNotifier extends QObject {
- protected QSocketNotifier(Class dummy){super((Class) null);}
+public class TQSocketNotifier extends TQObject {
+ protected TQSocketNotifier(Class dummy){super((Class) null);}
public static final int Read = 0;
public static final int Write = 1;
public static final int Exception = 2;
- public native QMetaObject metaObject();
+ public native TQMetaObject metaObject();
public native String className();
- public QSocketNotifier(int socket, int arg2, QObject parent, String name) {
+ public TQSocketNotifier(int socket, int arg2, TQObject parent, String name) {
super((Class) null);
- newQSocketNotifier(socket,arg2,parent,name);
+ newTQSocketNotifier(socket,arg2,parent,name);
}
- private native void newQSocketNotifier(int socket, int arg2, QObject parent, String name);
- public QSocketNotifier(int socket, int arg2, QObject parent) {
+ private native void newTQSocketNotifier(int socket, int arg2, TQObject parent, String name);
+ public TQSocketNotifier(int socket, int arg2, TQObject parent) {
super((Class) null);
- newQSocketNotifier(socket,arg2,parent);
+ newTQSocketNotifier(socket,arg2,parent);
}
- private native void newQSocketNotifier(int socket, int arg2, QObject parent);
- public QSocketNotifier(int socket, int arg2) {
+ private native void newTQSocketNotifier(int socket, int arg2, TQObject parent);
+ public TQSocketNotifier(int socket, int arg2) {
super((Class) null);
- newQSocketNotifier(socket,arg2);
+ newTQSocketNotifier(socket,arg2);
}
- private native void newQSocketNotifier(int socket, int arg2);
+ private native void newTQSocketNotifier(int socket, int arg2);
public native int socket();
public native int type();
public native boolean isEnabled();
public native void setEnabled(boolean arg1);
public static native String tr(String arg1, String arg2);
public static native String tr(String arg1);
- public native boolean event(QEvent arg1);
+ public native boolean event(TQEvent arg1);
/** Deletes the wrapped C++ instance */
protected native void finalize() throws InternalError;
/** Delete the wrapped C++ instance ahead of finalize() */
@@ -7,7 +7,7 @@ import org.kde.qt.Qt;
*************************************************
$Id$
-* Definition of QSocketNotifier class
+* Definition of TQSocketNotifier class
* Created : 951114
@@ -33,46 +33,46 @@ import org.kde.qt.Qt;
* Contact info@trolltech.com if any conditions of this licensing are
not clear to you.
-********************************************** See {@link QSocketNotifierSignals} for signals emitted by QSocketNotifier
+********************************************** See {@link TQSocketNotifierSignals} for signals emitted by TQSocketNotifier
*/